===============================
Boundary and initial conditions
===============================

SWAN boundary and initial conditions commands
 
Boundary
~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.boundary.BOUNDSPEC
   rompy_swan.components.boundary.BOUNDNEST1
   rompy_swan.components.boundary.BOUNDNEST2
   rompy_swan.components.boundary.BOUNDNEST3

Initial conditions
~~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.boundary.INITIAL
